==> igniteui-react-16.16.2.tgz: package/esm2015/lib/IconButton.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ButtonBase } from "./ButtonBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { IconButtonVariant_$type } from "./IconButtonVariant";
/**
 * @hidden
 */
export let IconButton = /*@__PURE__*/ (() => {
    class IconButton extends ButtonBase {
        get x() {
            let ret_ = this.h.c("name");
            return ret_;
        }
        set x(a) {
            let value_ = a;
            this.h.i("name", value_);
        }
        get w() {
            let ret_ = this.h.c("collection");
            return ret_;
        }
        set w(a) {
            let value_ = a;
            this.h.i("collection", value_);
        }
        get v() {
            let ret_ = this.h.c("mirrored");
            return ret_;
        }
        set v(a) {
            let value_ = a;
            this.h.i("mirrored", value_);
        }
        get u() {
            let ret_ = this.h.c("variant");
            ret_ = enumGetBox(IconButtonVariant_$type, EnumUtil.getEnumValue(IconButtonVariant_$type, EnumUtil.parse(IconButtonVariant_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(IconButtonVariant_$type, ret_);
        }
        set u(a) {
            let value_ = enumGetBox(IconButtonVariant_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.h.i("variant", value_);
        }
        y(a, b, c) {
            this.nativeElement.registerIcon(a, b, c);
        }
        z(a, b, c) {
            this.nativeElement.registerIconFromText(a, b, c);
        }
    }
    IconButton.$t = /*@__PURE__*/ markType(IconButton, 'IconButton', ButtonBase.$);
    return IconButton;
})();

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/IconButton.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ButtonBase } from "./ButtonBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { IconButtonVariant_$type } from "./IconButtonVariant";
/**
 * @hidden
 */
export let IconButton = /*@__PURE__*/ (() => {
    class IconButton extends ButtonBase {
        get y() {
            let ret_ = this.h.n("name");
            return ret_;
        }
        set y(a) {
            let value_ = a;
            this.h.v("name", value_);
        }
        get x() {
            let ret_ = this.h.n("collection");
            return ret_;
        }
        set x(a) {
            let value_ = a;
            this.h.v("collection", value_);
        }
        get w() {
            let ret_ = this.h.n("mirrored");
            return ret_;
        }
        set w(a) {
            let value_ = a;
            this.h.v("mirrored", value_);
        }
        get v() {
            let ret_ = this.h.n("variant");
            ret_ = enumGetBox(IconButtonVariant_$type, EnumUtil.getEnumValue(IconButtonVariant_$type, this.h.f(IconButtonVariant_$type, ret_)));
            return EnumUtil.getEnumValue(IconButtonVariant_$type, ret_);
        }
        set v(a) {
            let value_ = enumGetBox(IconButtonVariant_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.h.v("variant", value_);
        }
        z(a, b, c) {
            this.nativeElement.registerIcon(this.h.i(a), this.h.i(b), this.h.i(c));
        }
        aa(a, b, c) {
            this.nativeElement.registerIconFromText(this.h.i(a), this.h.i(b), this.h.i(c));
        }
    }
    IconButton.$t = /*@__PURE__*/ markType(IconButton, 'IconButton', ButtonBase.$);
    return IconButton;
})();
